summaryrefslogtreecommitdiff
path: root/vendor/ruflin/elastica/lib/Elastica/Facet/DateHistogram.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/ruflin/elastica/lib/Elastica/Facet/DateHistogram.php')
-rw-r--r--vendor/ruflin/elastica/lib/Elastica/Facet/DateHistogram.php30
1 files changed, 22 insertions, 8 deletions
diff --git a/vendor/ruflin/elastica/lib/Elastica/Facet/DateHistogram.php b/vendor/ruflin/elastica/lib/Elastica/Facet/DateHistogram.php
index 803f54a3..c47eddab 100644
--- a/vendor/ruflin/elastica/lib/Elastica/Facet/DateHistogram.php
+++ b/vendor/ruflin/elastica/lib/Elastica/Facet/DateHistogram.php
@@ -1,23 +1,23 @@
<?php
-
namespace Elastica\Facet;
/**
* Implements the Date Histogram facet.
*
- * @category Xodoa
- * @package Elastica
* @author Raul Martinez Jr <juneym@gmail.com>
- * @link http://www.elasticsearch.org/guide/reference/api/search/facets/date-histogram-facet.html
+ *
+ * @link http://www.elastic.co/guide/en/elasticsearch/reference/current/search-facets-date-histogram-facet.html
* @link https://github.com/elasticsearch/elasticsearch/issues/591
+ * @deprecated Facets are deprecated and will be removed in a future release. You are encouraged to migrate to aggregations instead.
*/
class DateHistogram extends Histogram
{
/**
* Set the time_zone parameter
*
- * @param string $tzOffset
- * @return \Elastica\Facet\DateHistogram
+ * @return $this
*/
public function setTimezone($tzOffset)
{
@@ -25,16 +25,30 @@ class DateHistogram extends Histogram
}
/**
+ * Set the factor parameter.
+ *
+ * @param int $factor
+ *
+ * @return $this
+ */
+ public function setFactor($factor)
+ {
+ return $this->setParam('factor', $factor);
+ }
+
+ /**
* Creates the full facet definition, which includes the basic
* facet definition of the parent.
*
* @see \Elastica\Facet\AbstractFacet::toArray()
+ *
* @throws \Elastica\Exception\InvalidException When the right fields haven't been set.
+ *
* @return array
*/
public function toArray()
{
- /**
+ /*
* Set the range in the abstract as param.
*/
$this->_setFacetParam('date_histogram', $this->_params);
@@ -1,23 +1,23 @@
{
/**
- * Set the time_zone parameter
+ * Set the time_zone parameter.
+ *
+ * @param string $tzOffset
*